@@ -81,6 +81,11 @@ get_deb (DVContents *deb)
 		"*.udeb");
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER(chooser), filter);
 	filter = gtk_file_filter_new ();
+	gtk_file_filter_set_name (filter, _("Debian translation packages *.tdeb"));
+	gtk_file_filter_add_pattern (filter, 
+		"*.tdeb");
+	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER(chooser), filter);
+	filter = gtk_file_filter_new ();
 	gtk_file_filter_set_name (filter, _("Debian package changes *.changes"));
 	gtk_file_filter_add_pattern (filter, 
 		"*.changes");
