@@ -22,7 +22,7 @@
 #ifndef _CALLBACKS_H
 #define _CALLBACKS_H
 
-#include <gnome.h>
+#include <libgnome/libgnome.h>
 
 enum
 {
